# uw-restclients-msca
Restclient providing access to UW MSCA API

[![Build Status](https://github.com/uw-it-aca/uw-restclients-msca/workflows/tests/badge.svg?branch=main)](https://github.com/uw-it-aca/uw-restclients-msca/actions)
[![Coverage Status](https://coveralls.io/repos/github/uw-it-aca/uw-restclients-msca/badge.svg?branch=main)](https://coveralls.io/github/uw-it-aca/uw-restclients-msca?branch=main)
[![PyPi Version](https://img.shields.io/pypi/v/uw-restclients-msca.svg)](https://pypi.python.org/pypi/uw-restclients-msca)
![Python versions](https://img.shields.io/pypi/pyversions/uw-restclients-msca.svg)
